Skip to contents

A data set consisting of Fst values between all pairs of Hilaria jamesii empirical sampling locations contained in hija_struc.

Usage

hija_fst

Format

An object of class "dist" with 16 rows and 16 columns. Floats below the diagonal indicate pairwise Fst values. Row and column names indicate sampling site - see hija_struc.

References

Massatti R & Knowles LL. (2020) The historical context of contemporary climatic adaptation: a case study in the climatically dynamic and environmentally complex southwestern United States. Ecography 43(5) 735-746.

See also

hija_struc, hija_raster

Examples

if (FALSE) { # \dontrun{
   location <- as.matrix(hija_struc[,2:3])
   geoDist <- raster::pointDistance(location,longlat=T)
   geoDist <- as.dist(geoDist)
   transition_layer <- gdistance::transition(hija_raster, transitionFunction=mean, directions=8)
   corrected_transC <- gdistance::geoCorrection(transition_layer,type="c",scl=T)
   costDist <- gdistance::costDistance(corrected_transC,location)
   cor(hija_fst,geoDist)
   cor(hija_fst,costDist) 
} # }