Skip to contents

A data set consisting of 214 verified and georeferenced herbarium voucher specimens for Hilaria jamesii occurring within the extent of hija_raster. These herbarium specimens were downloaded from the SEINet data portal (https://swbiodiversity.org/seinet/).

Usage

hija_herb

Format

A data frame consisting of 2 columns and 214 rows. Columns contain longitude and latitude in decimal degrees and rows contain unique herbarium specimens.

References

Massatti R & Knowles LL. (2020) The historical context of contemporary climatic adaptation: a case study in the climatically dynamic and environmentally complex southwestern United States. Ecography 43(5) 735-746.

See also

hija_struc

Examples

if (FALSE) { # \dontrun{
   plot(hija_raster)
   points(hija_herb, pch=24, col= 'black', bg='red')
} # }