A data set containing location information and ancestry coefficients for Hilaria jamesii sampling locations.
Format
A data frame with 16 rows and 6 columns. Columns include: 1 - sampling location name; 2 - decimal longitude; 3 - decimal latitude; 4 to the number of genetic axes - ancestry coefficients per genetic axis.
References
Massatti R & Knowles LL. (2020) The historical context of contemporary climatic adaptation: a case study in the climatically dynamic and environmentally complex southwestern United States. Ecography 43(5) 735-746.
Examples
if (FALSE) { # \dontrun{
ex_raster <- raster::aggregate(hija_raster,fact=16) #Cells in embedded raster are aggregated to reduce computation time
pp <- popmaps(input_raster=ex_raster,input_locs=hija_struc,empirical_pt_dist=5,num_sites=15,num_tested=4,popmod=-0.05,threshold=0,surface='G')
popmap_viz(pop_raster_list=pp,input_locs=hija_struc,input_raster=ex_raster,maptype='ancestry',crs="+init=epsg:5070",boundary_width=-0.01)
} # }